# CircuitCalculator

This project is a simple calculator for electrical circuits. It allows users to input the values of various components in a circuit (such as resistors, capacitors, and voltage sources) and will then calculate various properties of the circuit, such as the current and voltage at different points.

## Usage

To use this calculator, there are different interfaces. The most convenient one is to use the `SimpleCircuit` module, which is based somehow on the [schemdraw](https://schemdraw.readthedocs.io/en/latest/) package. There are several IPython notebook examples can be found [here](examples/examples.md).

## Components Supported

Currently, the following components are supported:

- Resistors
- Capacitors
- Voltage sources
- Current sources

## Contribution

This project is open-source and contributions are welcome. If you would like to contribute, please fork the repository and make a pull request.

## License

This project is licensed under the MIT License.

## Contact

If you have any questions or issues, please open an issue on the GitHub repository.





